 /*
  * UAE - The Un*x Amiga Emulator
  *
  * Target specific stuff, SVGAlib version
  *
  * Copyright 1997, 1998 Bernd Schmidt
  */

#define TARGET_NAME "svgalib"

#define OPTIONSFILENAME ".uaerc"
#define OPTIONS_IN_HOME

#define DEFPRTNAME "lpr"
#define DEFSERNAME "/dev/ttyS1"

#define PICASSO96_SUPPORTED

#define write_log write_log_standard
